@@ -304,6 +304,13 @@ def _ShowFailoverReplicaDeprecationWarning():
   )
 
 
+def _ShowAcceleratedReplicaModeWarning():
+  log.warning(
+      'Setting the accelerated replica mode for a replica may '
+      'cause recreate of the replica instance in case of crash.'
+  )
+
+
 class _BaseInstances(object):
   """Common utility functions for sql instance commands."""
 
@@ -441,6 +448,22 @@ class _BaseInstances(object):
         settings.ipConfiguration.pscConfig = sql_messages.PscConfig()
       settings.ipConfiguration.pscConfig.allowedConsumerProjects = []
 
+    if args.IsKnownAndSpecified('psc_network_attachment_uri'):
+      if not settings.ipConfiguration:
+        settings.ipConfiguration = sql_messages.IpConfiguration()
+      if not settings.ipConfiguration.pscConfig:
+        settings.ipConfiguration.pscConfig = sql_messages.PscConfig()
+      settings.ipConfiguration.pscConfig.networkAttachmentUri = (
+          args.psc_network_attachment_uri
+      )
+
+    if args.IsKnownAndSpecified('clear_psc_network_attachment_uri'):
+      if not settings.ipConfiguration:
+        settings.ipConfiguration = sql_messages.IpConfiguration()
+      if not settings.ipConfiguration.pscConfig:
+        settings.ipConfiguration.pscConfig = sql_messages.PscConfig()
+      settings.ipConfiguration.pscConfig.networkAttachmentUri = ''
+
     if args.deletion_protection is not None:
       settings.deletionProtectionEnabled = args.deletion_protection
 
@@ -489,6 +512,9 @@ class _BaseInstances(object):
       if not settings.ipConfiguration:
         settings.ipConfiguration = sql_messages.IpConfiguration()
       settings.ipConfiguration.serverCaPool = args.server_ca_pool
+    # Customers can set `--server-ca-pool=''` to explicitly clear the
+    # server_ca_pool field.
+    if args.IsKnownAndSpecified('server_ca_pool') and args.server_ca_pool:
       if (
           settings.ipConfiguration.serverCaMode
           != sql_messages.IpConfiguration.ServerCaModeValueValuesEnum.CUSTOMER_MANAGED_CAS_CA
@@ -511,6 +537,18 @@ class _BaseInstances(object):
           ),
       )
 
+    if args.IsKnownAndSpecified('custom_subject_alternative_names'):
+      if not settings.ipConfiguration:
+        settings.ipConfiguration = sql_messages.IpConfiguration()
+      settings.ipConfiguration.customSubjectAlternativeNames = (
+          args.custom_subject_alternative_names
+      )
+
+    if args.IsKnownAndSpecified('clear_custom_subject_alternative_names'):
+      if not settings.ipConfiguration:
+        settings.ipConfiguration = sql_messages.IpConfiguration()
+      settings.ipConfiguration.customSubjectAlternativeNames = []
+
     # BETA args.
     if IsBetaOrNewer(release_track):
       if args.IsSpecified('storage_auto_increase_limit'):
@@ -539,17 +577,21 @@ class _BaseInstances(object):
             args.replication_lag_max_seconds_for_recreate
         )
 
-      if args.IsKnownAndSpecified('custom_subject_alternative_names'):
-        if not settings.ipConfiguration:
-          settings.ipConfiguration = sql_messages.IpConfiguration()
-        settings.ipConfiguration.customSubjectAlternativeNames = (
-            args.custom_subject_alternative_names
+      if args.IsKnownAndSpecified('enable_db_aligned_atomic_writes'):
+        if not settings.dbAlignedAtomicWritesConfig:
+          settings.dbAlignedAtomicWritesConfig = (
+              sql_messages.DbAlignedAtomicWritesConfig()
+          )
+        settings.dbAlignedAtomicWritesConfig.dbAlignedAtomicWrites = (
+            args.enable_db_aligned_atomic_writes
         )
 
-      if args.IsKnownAndSpecified('clear_custom_subject_alternative_names'):
-        if not settings.ipConfiguration:
-          settings.ipConfiguration = sql_messages.IpConfiguration()
-        settings.ipConfiguration.customSubjectAlternativeNames = []
+      if args.IsKnownAndSpecified('enable_accelerated_replica_mode'):
+        _ShowAcceleratedReplicaModeWarning()
+        settings.acceleratedReplicaMode = args.enable_accelerated_replica_mode
+
+      if args.IsKnownAndSpecified('enable_auto_upgrade_minor_version'):
+        settings.autoUpgradeEnabled = True
 
     return settings
 
@@ -582,9 +624,10 @@ class _BaseInstances(object):
     if backup_configuration:
       cls.AddBackupConfigToSettings(settings, backup_configuration)
 
-    settings.databaseFlags = reducers.DatabaseFlags(
-        sql_messages, original_settings, database_flags=args.database_flags
-    )
+    if args and args.IsKnownAndSpecified('database_flags'):
+      settings.databaseFlags = reducers.DatabaseFlags(
+          sql_messages, original_settings, database_flags=args.database_flags
+      )
 
     settings.maintenanceWindow = reducers.MaintenanceWindow(
         sql_messages,
@@ -687,6 +730,22 @@ class _BaseInstances(object):
       if mcp_config is not None:
         settings.connectionPoolConfig = mcp_config
 
+      db_aligned_atomic_writes_config = reducers.DbAlignedAtomicWritesConfig(
+          sql_messages,
+          db_aligned_atomic_writes=args.enable_db_aligned_atomic_writes,
+      )
+      if db_aligned_atomic_writes_config is not None:
+        settings.dbAlignedAtomicWritesConfig = db_aligned_atomic_writes_config
+
+      final_backup_configuration = reducers.FinalBackupConfiguration(
+          sql_messages,
+          instance,
+          final_backup_enabled=args.final_backup,
+          final_backup_retention_days=args.final_backup_retention_days,
+      )
+      if final_backup_configuration:
+        cls.AddFinalBackupConfigToSettings(settings, final_backup_configuration)
+
     # ALPHA args.
     if _IsAlpha(release_track):
       pass
@@ -738,12 +797,13 @@ class _BaseInstances(object):
     if backup_configuration:
       cls.AddBackupConfigToSettings(settings, backup_configuration)
 
-    settings.databaseFlags = reducers.DatabaseFlags(
-        sql_messages,
-        original_settings,
-        database_flags=args.database_flags,
-        clear_database_flags=args.clear_database_flags,
-    )
+    if args and args.IsKnownAndSpecified('database_flags'):
+      settings.databaseFlags = reducers.DatabaseFlags(
+          sql_messages,
+          original_settings,
+          database_flags=args.database_flags,
+          clear_database_flags=args.clear_database_flags,
+      )
 
     settings.maintenanceWindow = reducers.MaintenanceWindow(
         sql_messages,
@@ -853,6 +913,22 @@ class _BaseInstances(object):
       )
       if updated_config is not None:
         settings.connectionPoolConfig = updated_config
+
+      final_backup_configuration = reducers.FinalBackupConfiguration(
+          sql_messages,
+          instance,
+          final_backup_enabled=args.final_backup,
+          final_backup_retention_days=args.final_backup_retention_days,
+      )
+      if final_backup_configuration:
+        cls.AddFinalBackupConfigToSettings(settings, final_backup_configuration)
+
+      if args.IsKnownAndSpecified('unc_mappings'):
+        settings.uncMappings = reducers.UncMappings(
+            sql_messages,
+            unc_mappings=args.unc_mappings,
+            clear_unc_mappings=args.clear_unc_mappings,
+        )
     return settings
 
   @classmethod
@@ -932,6 +1008,11 @@ class _BaseInstances(object):
         sql_messages, args, original, release_track
     )
 
+    if args.IsKnownAndSpecified('enforce_new_sql_network_architecture'):
+      instance_resource.sqlNetworkArchitecture = (
+          sql_messages.DatabaseInstance.SqlNetworkArchitectureValueValuesEnum.NEW_NETWORK_ARCHITECTURE
+      )
+
     if args.IsKnownAndSpecified('master_instance_name'):
       replication = (
           sql_messages.Settings.ReplicationTypeValueValuesEnum.ASYNCHRONOUS
@@ -1038,13 +1119,12 @@ class _BaseInstances(object):
           ]
       )
 
-    if IsBetaOrNewer(release_track):
-      if args.IsKnownAndSpecified('instance_type'):
-        instance_resource.instanceType = _ParseInstanceType(
-            sql_messages, args.instance_type
-        )
-      if args.IsKnownAndSpecified('node_count'):
-        instance_resource.nodeCount = args.node_count
+    if args.IsKnownAndSpecified('instance_type'):
+      instance_resource.instanceType = _ParseInstanceType(
+          sql_messages, args.instance_type
+      )
+    if args.IsKnownAndSpecified('node_count'):
+      instance_resource.nodeCount = args.node_count
 
     return instance_resource
 
@@ -1076,6 +1156,10 @@ class _BaseInstances(object):
       instance_resource.sqlNetworkArchitecture = (
           sql_messages.DatabaseInstance.SqlNetworkArchitectureValueValuesEnum.NEW_NETWORK_ARCHITECTURE
       )
+    if args.enforce_new_sql_network_architecture:
+      instance_resource.sqlNetworkArchitecture = (
+          sql_messages.DatabaseInstance.SqlNetworkArchitectureValueValuesEnum.NEW_NETWORK_ARCHITECTURE
+      )
 
     if args.IsKnownAndSpecified('switch_transaction_logs_to_cloud_storage'):
       instance_resource.switchTransactionLogsToCloudStorageEnabled = (
@@ -1094,6 +1178,17 @@ class _BaseInstances(object):
     ):
       api_util.InstancesV1Beta4.PrintAndConfirmSimulatedMaintenanceEvent()
 
+    if IsBetaOrNewer(release_track) and args.IsSpecified(
+        'reconcile_psa_networking'
+    ):
+      if instance_resource.settings.ipConfiguration is None:
+        instance_resource.settings.ipConfiguration = (
+            sql_messages.IpConfiguration()
+        )
+      instance_resource.settings.ipConfiguration.privateNetwork = (
+          original.settings.ipConfiguration.privateNetwork
+      )
+
     if args.IsKnownAndSpecified('failover_dr_replica_name'):
       replication_cluster = sql_messages.ReplicationCluster()
       replication_cluster.failoverDrReplicaName = (
@@ -1109,13 +1204,12 @@ class _BaseInstances(object):
           args.include_replicas_for_major_version_upgrade
       )
 
-    if IsBetaOrNewer(release_track):
-      if args.IsKnownAndSpecified('instance_type'):
-        instance_resource.instanceType = _ParseInstanceType(
-            sql_messages, args.instance_type
-        )
-      if args.IsKnownAndSpecified('node_count'):
-        instance_resource.nodeCount = args.node_count
+    if args.IsKnownAndSpecified('instance_type'):
+      instance_resource.instanceType = _ParseInstanceType(
+          sql_messages, args.instance_type
+      )
+    if args.IsKnownAndSpecified('node_count'):
+      instance_resource.nodeCount = args.node_count
 
     return instance_resource
 
@@ -1132,6 +1226,10 @@ class InstancesV1Beta4(_BaseInstances):
   def AddBackupConfigToSettings(settings, backup_config):
     settings.backupConfiguration = backup_config
 
+  @staticmethod
+  def AddFinalBackupConfigToSettings(settings, final_backup_config):
+    settings.finalBackupConfig = final_backup_config
+
   @staticmethod
   def SetIpConfigurationEnabled(settings, assign_ip):
     settings.ipConfiguration.ipv4Enabled = assign_ip
