@@ -23,6 +23,10 @@ from googlecloudsdk.command_lib.container import flags
 from surface.container.clusters import create
 
 # Select which flags are auto flags
+# Arguments for "clusters create-auto" should also be added to "clusters create"
+# Unless there is a good reason to exclude them because features should support
+# both GKE Standard and Autopilot.
+# LINT.IfChange(auto_flags)
 auto_flags = [
     'args',
     'clusterversion',
@@ -67,7 +71,10 @@ auto_flags = [
     'enableK8sTokensViaDns',
     'enableDefaultComputeClass',
     'enableK8sCertsViaDns',
+    'membershipType',
+    'secretSyncConfig',
 ]
+# LINT.ThenChange()
 
 # Change default flag values in create-auto
 flag_overrides = {
@@ -95,8 +102,8 @@ def AddAutoFlags(parser, release_track):
   flags.AddAutoprovisioningResourceManagerTagsCreate(parser)
   flags.AddAdditiveVPCScopeFlags(parser)
   flags.AddIPAliasRelatedFlags(parser, autopilot=True)
-  flags.AddEnableConfidentialNodesFlag(parser, hidden=True)
-  flags.AddEnableLustreCSIDriverFlag(parser, hidden=True)
+  flags.AddEnableConfidentialNodesFlag(parser)
+  flags.AddEnableLustreCSIDriverFlag(parser, hidden=False)
   flags.AddEnableRayOperatorFlag(parser, hidden=False)
   flags.AddEnableRayClusterMonitoring(parser, hidden=False)
   flags.AddEnableRayClusterLogging(parser, hidden=False)
@@ -107,7 +114,7 @@ def AddAutoFlags(parser, release_track):
   flags.AddClusterTierFlag(parser)
   flags.AddKubecontextOverrideFlag(parser)
   flags.AddAnonymousAuthenticationConfigFlag(parser)
-  flags.AddEnableLegacyLustrePortFlag(parser, hidden=True)
+  flags.AddEnableLegacyLustrePortFlag(parser, hidden=False)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
